Crate bock_parser

Crate bock_parser 

Bock parser — transforms a token stream into a typed abstract syntax tree.

Usage

let parser = Parser::new(tokens, &source_file);
let module = parser.parse_module();

Structs

Parser
The Bock parser. Transforms a flat token stream into a typed Module AST.